Public Class frmMain
  ' This form provides a demonstration of each function call provided by the
  ' DeVaSys USBI2CIO Device Application Programming Interface (DAPI)

'
Private Sub frmMain_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
  DoAll()
End Sub

'
Private Sub DoAll()

  DemoGetDllAndDriverVersions()
  If (DemoGetDeviceCount()) Then
    DemoGetDeviceInfo()
    txtMain.Text = txtMain.Text & vbCrLf
    If (OpenDiHandle()) Then
      txtMain.Text = txtMain.Text & "Opened handle to UsbI2cIo board" & vbCrLf
      DemoGetSerialId()
      DemoDeviceIo()
      DemoDeviceI2c()
      CloseDiHandle()
      txtMain.Text = txtMain.Text & "Closed handle to UsbI2cIo board" & vbCrLf
    Else
      txtMain.Text = txtMain.Text & "Error: Failed to open handle to UsbI2cIo board" & vbCrLf
    End If
  End If

End Sub

'
Private Function DemoDetectDevice() As Boolean

  If (DAPI_DetectDevice(modMain.hDevInstance)) Then
    txtMain.Text = txtMain.Text & "UsbI2cIo device detected" & vbCrLf
    DemoDetectDevice = True
  Else
    txtMain.Text = txtMain.Text & "UsbI2cIo device not detected" & vbCrLf
    DemoDetectDevice = False
  End If

End Function

'
Private Function DemoGetDeviceCount()

  Dim byCount As Byte

  byCount = DAPI_GetDeviceCount(sDevSymName)
  txtMain.Text = txtMain.Text & vbCrLf & "Attached UsbI2cIo Device(s) = " & Str(byCount) & vbCrLf
  DemoGetDeviceCount = byCount

End Function

'
Private Sub DemoGetDllAndDriverVersions()

  Dim wVersion As DAPI_WORD

  wVersion = DAPI_GetDllVersion()
  txtMain.Text = txtMain.Text & vbCrLf & "UsbI2cio DLL Version = " & Str(wVersion.hi) & "." & Str(wVersion.lo) & vbCrLf

  wVersion = DAPI_GetDriverVersion()
  txtMain.Text = txtMain.Text & "UsbI2cIo Driver Version = " & Str(wVersion.hi) & "." & Str(wVersion.lo) & vbCrLf

End Sub

'
Private Sub DemoGetFirmwareVersion()

  Dim wVersion As DAPI_WORD

  If (DAPI_GetFirmwareVersion(modMain.hDevInstance, wVersion)) Then
    txtMain.Text = txtMain.Text & "    Firmware Version = " & Str(wVersion.hi) & "." & Str(wVersion.lo) & vbCrLf
  Else
    txtMain.Text = txtMain.Text & "    Error: Firmware Version = Unavailable" & vbCrLf
  End If

End Sub

'
Private Sub DemoGetSerialId()

  Dim Id As DAPI_ID = New DAPI_ID

  If (DAPI_GetSerialId(modMain.hDevInstance, Id)) Then
    txtMain.Text = txtMain.Text & "Serial ID = " & Id.sSerial & vbCrLf
  Else
    txtMain.Text = txtMain.Text & "Error: Serial ID = Unavalable" & vbCrLf
  End If

End Sub

'
Private Sub DemoGetDeviceInfo()

  Dim DeviceInfoArray As DAPI_DEV_INFO_ARRAY = New DAPI_DEV_INFO_ARRAY
  Dim byCount As Byte
  Dim i As Byte

  byCount = DAPI_GetDeviceInfo(modMain.sDevSymName, DeviceInfoArray)
  If (byCount > 0) Then
    txtMain.Text = txtMain.Text & "Device Info:" & vbCrLf
    For i = 0 To (byCount - 1) Step 1
      txtMain.Text = txtMain.Text & "  Device Instance = " & Str(DeviceInfoArray.DevInfo(i).byInstance) _
      & ", SerialId = " & DeviceInfoArray.DevInfo(i).sSerial & vbCrLf
      DemoOpenDeviceBySerialId(DeviceInfoArray.DevInfo(i).sSerial)
    Next i
  Else
    txtMain.Text = txtMain.Text & "Error: Device Info = Unavalable" & vbCrLf
  End If

End Sub

'
Private Function DemoOpenDeviceBySerialId(ByVal sSerial As String) As Boolean

  ' now let's close our handle
   CloseDiHandle()

  ' get a handle to a board, using the SerialId of the board
  modMain.hDevInstance = DAPI_OpenDeviceBySerialId(sDevSymName, sSerial)

  ' test result of function call and flag success or failure
  If (modMain.hDevInstance <> INVALID_HANDLE_VALUE) Then
    txtMain.Text = txtMain.Text & "    Opened handle to device using Serial ID " _
    & sSerial & vbCrLf
    DemoGetFirmwareVersion()
    DemoOpenDeviceBySerialId = 1
  Else
    txtMain.Text = txtMain.Text & "    Error: Failed to open device using Serial ID " _
    & sSerial & vbCrLf
    DemoOpenDeviceBySerialId = 0
  End If

End Function

'
Private Sub DemoDeviceIo()

  Dim IoPortConfig As UInteger
  Dim IoPortMask As UInteger
  Dim IoPortData As UInteger

  If (DAPI_GetIoConfig(modMain.hDevInstance, IoPortConfig)) Then
    txtMain.Text = txtMain.Text & "Read I/O Configuration 0x" & Hex(IoPortConfig) _
    & " from UsbI2cIo board" & vbCrLf
  Else
    txtMain.Text = txtMain.Text & "Error I/O Configuration = Unavalable" & vbCrLf
  End If

  IoPortConfig = &H0
  If (DAPI_ConfigIoPorts(modMain.hDevInstance, IoPortConfig)) Then
    txtMain.Text = txtMain.Text & "Wrote I/O Configuration 0x" & Hex(IoPortConfig) _
    & " to UsbI2cIo board" & vbCrLf
  Else
    txtMain.Text = txtMain.Text & "Error: Failed to write I/O Configuration to UsbI2cIo board" & vbCrLf
  End If


  If (DAPI_GetIoConfig(modMain.hDevInstance, IoPortConfig)) Then
    txtMain.Text = txtMain.Text & "Read I/O Configuration 0x" & Hex(IoPortConfig) _
    & " from UsbI2cIo board" & vbCrLf
  Else
    txtMain.Text = txtMain.Text & "Error I/O Configuration = Unavalable" & vbCrLf
  End If

  'Declare Function DAPI_ReadIoPorts Lib "UsbI2cIo.dll" ( _
  '  ByVal hDevInstance As Integer, _
  '  ByRef pulIoPortData As UInt32) _
  '  As Boolean
  If (DAPI_ReadIoPorts(modMain.hDevInstance, IoPortData)) Then
    txtMain.Text = txtMain.Text & "Read I/O Data 0x" & Hex(IoPortData) _
    & " from UsbI2cIo board" & vbCrLf
  Else
    txtMain.Text = txtMain.Text & "Error: I/O Data = Unavalable" & vbCrLf
  End If

'  IoPortMask = &HFFFFFFFF
  IoPortMask = 4294967295
  IoPortData = &H1
  If (DAPI_WriteIoPorts(modMain.hDevInstance, IoPortData, IoPortMask)) Then
    txtMain.Text = txtMain.Text & "Wrote I/O Data 0x" & Hex(IoPortData) _
    & " I/O Mask 0x" & Hex(IoPortMask) & " to UsbI2cIo board" & vbCrLf
  Else
    txtMain.Text = txtMain.Text & "Error: Failed to write I/O Data and I/O Mask to UsbI2cIo board" & vbCrLf
  End If

  If (DAPI_ReadIoPorts(modMain.hDevInstance, IoPortData)) Then
    txtMain.Text = txtMain.Text & "Read I/O Data 0x" & Hex(IoPortData) _
    & " from UsbI2cIo board" & vbCrLf
  Else
    txtMain.Text = txtMain.Text & "Error: I/O Data = Unavalable" & vbCrLf
  End If

End Sub

'
Private Sub DemoDeviceI2c()

  Dim I2cTrans As DAPI_I2C_TRANS = New DAPI_I2C_TRANS
  Dim lResult As Integer
  Dim i As Integer
  Dim wCount As Integer

  I2cTrans.byDevId = &HA2
  I2cTrans.byType = DAPI_I2C_TRANS_TYPE.ADR16
  I2cTrans.wMemAddr.hi = &H3F
  I2cTrans.wMemAddr.lo = &H0
  I2cTrans.wCount.hi = 0
  I2cTrans.wCount.lo = 8

  wCount = (CInt(I2cTrans.wCount.hi) * 256) + I2cTrans.wCount.lo

  lResult = DAPI_ReadI2c(modMain.hDevInstance, I2cTrans)
  txtMain.Text = txtMain.Text & "Setting up I2C_TRANS structure for call to ReadI2c():" & vbCrLf
  txtMain.Text = txtMain.Text & "  I2cTrans.byDevId: 0x" & Hex(I2cTrans.byDevId) & vbCrLf
  txtMain.Text = txtMain.Text & "  I2cTrans.byType: 0x" & Hex(I2cTrans.byType) & vbCrLf
  txtMain.Text = txtMain.Text & "  I2cTrans.wMemAddr.hi: 0x" & Hex(I2cTrans.wMemAddr.hi) & vbCrLf
  txtMain.Text = txtMain.Text & "  I2cTrans.wMemAddr.lo: 0x" & Hex(I2cTrans.wMemAddr.lo) & vbCrLf
  txtMain.Text = txtMain.Text & "  I2cTrans.wCount.hi: 0x" & Hex(I2cTrans.wCount.hi) & vbCrLf
  txtMain.Text = txtMain.Text & "  I2cTrans.wCount.lo: 0x" & Hex(I2cTrans.wCount.lo) & vbCrLf
  If (lResult = wCount) Then
    txtMain.Text = txtMain.Text & "ReadI2c call was successful" & vbCrLf & "  I2cTrans.Data(): {"
    For i = 0 To (lResult - 1) Step 1
    txtMain.Text = txtMain.Text & " 0x" & Hex(I2cTrans.Data(i))
    Next i
    txtMain.Text = txtMain.Text & " }" & vbCrLf
  Else
    txtMain.Text = txtMain.Text & "Error: ReadI2c call failed" & vbCrLf
  End If

End Sub

Private Sub cmdExecute_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdExecute.Click
  txtMain.Text = ""
  DoAll()
End Sub

Private Sub cmdExit_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdExit.Click
  Me.Close()
End Sub

End Class
