Option Explicit On
Imports System.Runtime.InteropServices

Module modUsbI2cIoDAPI
  '
  ' This module file contains the necessary definitions, Structures, and declarations for accessing the
  ' functions provided by the UsbI2cIo API dll.
  ' UsbI2cIo Device Application Programming Interface (DAPI)
  '

  ' Global constants and enumerations definitions
  '
  ' UsbI2cIo maximum devices
  Public Const DAPI_MAX_DEVICES As Byte = 127

    ' I2C transaction constants
  Public Const DAPI_VR_SETUP_SIZE = 6
  Public Const DAPI_MAX_VR_DATA_SIZE = 1088
  Public Const DAPI_I2C_HEADER_SIZE = DAPI_VR_SETUP_SIZE
  Public Const DAPI_MAX_IO_DATA = DAPI_MAX_VR_DATA_SIZE
  Public Const DAPI_MAX_I2C_DATA = DAPI_MAX_VR_DATA_SIZE

  ' I2C Transaction Types
  Public Enum DAPI_I2C_TRANS_TYPE
    NOADR = 0
    ADR8 = 1
    ADR16 = 2
    NOADR_NS = 3
    XICOR = 4
  End Enum

  ' Block IO Modes
  Public Enum DAPI_IO_MODE
    SINGLE_IO = 0
    BLOCK_ABC = 1
    BLOCK_A = 2
    BLOCK_B = 3
    BLOCK_C = 4
    BLOCK_AB = 5
    BLOCK_BC = 6
    BLOCK_AC = 7
  End Enum

  ' Configurable Properties Index Values
  Public Enum DAPI_PROPERTY_INDEX
    WRCOMMAND_RDCOUNT = 0  ' when setting indicates command, when reading indicates property table size
    I2C_CONFIG = 1
    FAST_XFER_CONFIG = 2
    IO_CONFIG_GLOBAL = 3
    IO_CONFIG_PORTA = 4
    IO_CONFIG_PORTB = 5
    IO_CONFIG_PORTC = 6
    IO_OUTPUT_PORTA = 7
    IO_OUTPUT_PORTB = 8
    IO_OUTPUT_PORTC = 9
    DEBUG_CONFIG_GLOBAL = 10
    DEBUG_CONFIG_0 = 11
    DEBUG_CONFIG_1 = 12
    USER_0 = 13
    USER_1 = 14
    USER_2 = 15
    USER_3 = 16
    MAX_PROPERTY_BYTES = 17
  End Enum

  ' Configurable Properties Commands
  Public Enum DAPI_PROPERTY_COMMANDS
    STORE_TABLE_TO_EEPROM = 0
    LOAD_TABLE_FROM_EEPROM = 1
    DISABLE_EEPROM_TABLE = 2
    RESET_TO_DEFAULTS = 3
  End Enum

  ' Configurable Properties Bit Mappings
  Public Const DAPI_PROP_I2C_RETRIES_FIELD = &H7
  Public Const DAPI_PROP_I2C_IGNORE_NAK = &H8
  Public Const DAPI_PROP_I2C_POLL_EEPROM_ACK = &H10
  Public Const DAPI_PROP_I2C_RESERVED_FIELD = &HE0
  Public Const DAPI_PROP_FAST_XFER_RD_FIELD = &H7
  Public Const DAPI_PROP_FAST_XFER_RD_ENABLE = &H8
  Public Const DAPI_PROP_FAST_XFER_WR_FIELD = &H70
  Public Const DAPI_PROP_FAST_XFER_WR_ENABLE = &H80
  Public Const DAPI_PROP_IO_23BIT_MODE = &H1
  Public Const DAPI_PROP_DBG_MAX_DISPLAY_FIELD = &H7F
  Public Const DAPI_PROP_DBG_GLOBAL_ENABLE = &H80

  ' Global Structure definitions for UsbI2cIo API DLL (correspond to values in UsbI2cIo.h)
  '
  <StructLayout(LayoutKind.Sequential)> _
  Public Structure DAPI_WORD
    Public lo As Byte
    Public hi As Byte
  End Structure

  <StructLayout(LayoutKind.Sequential)> _
  Public Structure DAPI_I2C_TRANS
    Public byType As Byte
    Public byDevId As Byte
    Public wMemAddr As DAPI_WORD
    Public wCount As DAPI_WORD
    <MarshalAs(UnmanagedType.ByValArray, SizeConst:=DAPI_MAX_I2C_DATA)> _
    Public Data() As Byte
  End Structure

  <StructLayout(LayoutKind.Sequential, CharSet:=CharSet.Ansi)> _
  Public Structure DAPI_ID
    <MarshalAs(UnmanagedType.ByValTStr, SizeConst:=9)> _
    Public sSerial As String
  End Structure

  <StructLayout(LayoutKind.Sequential, CharSet:=CharSet.Ansi)> _
  Public Structure DAPI_DEV_INFO
    Public byInstance As Byte
    <MarshalAs(UnmanagedType.ByValTStr, SizeConst:=9)> _
    Public sSerial As String
  End Structure

  <StructLayout(LayoutKind.Sequential, CharSet:=CharSet.Ansi)> _
  Public Structure DAPI_DEV_INFO_ARRAY
    <MarshalAs(UnmanagedType.ByValArray, SizeConst:=DAPI_MAX_DEVICES * 10)> _
    Public DevInfo() As DAPI_DEV_INFO
  End Structure

  ' DLL function declarations
  '
  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_GetDllVersion() As DAPI_WORD
  End Function

  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_GetDriverVersion() As DAPI_WORD
  End Function

  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_GetFirmwareVersion( _
    ByVal hDevInstance As IntPtr, _
    ByRef pwVersion As DAPI_WORD) _
    As Boolean
  End Function

  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_GetDeviceCount( _
    ByVal lpsDevName As String) _
    As Byte
  End Function

  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_GetDeviceInfo( _
    ByVal lpsDevName As String, _
    ByRef lpDevInfo As DAPI_DEV_INFO_ARRAY) _
    As Byte
  End Function

  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_GetSerialId( _
    ByVal hDevInstance As IntPtr, _
    ByRef Id As DAPI_ID) _
    As Byte
  End Function

  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_DetectDevice( _
    ByVal hDevInstance As IntPtr) _
    As Boolean
  End Function

  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_OpenDeviceInstance( _
    ByVal lpsDevName As String, _
    ByVal byDevInstance As Byte) _
    As Integer
  End Function

  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_CloseDeviceInstance( _
    ByVal hDevInstance As IntPtr) _
    As Boolean
  End Function

  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_OpenDeviceBySerialId( _
    ByVal lpsDevName As String, _
    ByVal lpsSerialId As String) _
    As Integer
  End Function

  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_GetIoConfig( _
    ByVal hDevInstance As IntPtr, _
    ByRef uiIoPortConfig As UInteger) _
    As Boolean
  End Function

  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_ConfigIoPorts( _
    ByVal hDevInstance As IntPtr, _
    ByVal uiIoPortConfig As UInteger) _
    As Boolean
  End Function

  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_ReadIoPorts( _
    ByVal hDevInstance As IntPtr, _
    ByRef uiIoPortData As UInteger) _
    As Boolean
  End Function

  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_WriteIoPorts( _
    ByVal hDevInstance As IntPtr, _
    ByVal uiIoPortData As UInteger, _
    ByVal uiIoPortMask As UInteger) _
    As Boolean
  End Function

  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_ReadI2c( _
    ByVal hDevInstance As IntPtr, _
    ByRef TransI2c As DAPI_I2C_TRANS) _
    As Integer
  End Function

  'Integer _stdcall DAPI_BlockWriteIoPorts(HANDLE hDevInstance, WORD wBlockIoMode, WORD wBlockIoIndex, BYTE *pbyData, WORD wCount);
  'Integer _stdcall DAPI_BlockReadIoPorts(HANDLE hDevInstance, BYTE *pbyData, WORD wBlockIoMode, WORD wBlockIoIndex, WORD wCount);

  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_WriteI2c( _
    ByVal hDevInstance As IntPtr, _
    ByRef TransI2c As DAPI_I2C_TRANS) _
    As Integer
  End Function

  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_ReadDebugBuffer( _
    ByRef DebugBuf As Byte, _
    ByVal hDevInstance As IntPtr, _
    ByVal ulMaxBytes As Integer) _
    As Integer
  End Function

  '// generic USB transfer calls
  'BOOL _stdcall DAPI_TransferData(HANDLE hDevInstance, BYTE byEndpoint, PBYTE pBuffer, PULONG pulLength);
  '
  'BOOL _stdcall DAPI_SetVendorRequest(HANDLE hDevInstance,
  '                                    BYTE byRequest, WORD wValue, WORD wIndex, WORD wLength, PBYTE pbySetData);
  '
  'BOOL _stdcall DAPI_GetVendorRequest(HANDLE hDevInstance,
  '                                    PBYTE pbySetData, BYTE byRequest, WORD wValue, WORD wIndex, WORD wLength);

  ' property calls
  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_SetProperty( _
    ByVal hDevInstance As IntPtr, _
    ByVal byPropIndex As Byte, _
    ByVal byPropValue As Byte) _
    As Boolean
  End Function

  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_GetProperty( _
    ByVal hDevInstance As IntPtr, _
    ByRef pbyPropValue As Byte, _
    ByVal byPropIndex As Byte) _
    As Boolean
  End Function

  <DllImport("usbi2cio.dll")> _
  Public Function DAPI_GetLastFirmwareError( _
    ByVal hDevInstance As IntPtr, _
    ByRef plError As Integer) _
    As Boolean
  End Function

End Module